@@ -2,19 +2,12 @@ package Fennec::Listener::TB2;
 use strict;
 use warnings;
 
-use base 'Fennec::Listener';
-use Fennec::Util;
+use base 'Fennec::Listener::TB';
 
-die "Fennec Does not yet support Test::Builder2 as TB2 is itself incomplete.";
+use Test::Builder2;
 
-sub new {}
-sub terminate {}
-
-sub ok         { shift; Fennec::Util::tb2_ok( @_ )        }
-sub diag       { shift; Fennec::Util::tb2_diag( @_ )      }
-sub skip       { shift; Fennec::Util::tb2_skip( @_ )      }
-sub todo_start { shift; Fennec::Util::tb2_todo_start( @_ )}
-sub todo_end   { shift; Fennec::Util::tb2_todo_end( @_ )  }
+my $tb = Test::Builder2->singleton;
+$tb->formatter->show_tap_version(0);
 
 1;
 
